# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/clickhouse/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from doublecloud.clickhouse.v1 import config_pb2 as doublecloud_dot_clickhouse_dot_v1_dot_config__pb2
from doublecloud.v1 import cluster_pb2 as doublecloud_dot_v1_dot_cluster__pb2
from doublecloud.v1 import maintenance_pb2 as doublecloud_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'doublecloud/clickhouse/v1/cluster.proto\x12\x19\x64oublecloud.clickhouse.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&doublecloud/clickhouse/v1/config.proto\x1a\x1c\x64oublecloud/v1/cluster.proto\x1a doublecloud/v1/maintenance.proto\"\xd7\x07\n\x07\x43luster\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x1d\n\ncloud_type\x18\x03 \x01(\tR\tcloudType\x12\x1b\n\tregion_id\x18\x04 \x01(\tR\x08regionId\x12;\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x07 \x01(\tR\x0b\x64\x65scription\x12\x35\n\x06status\x18\x08 \x01(\x0e\x32\x1d.doublecloud.v1.ClusterStatusR\x06status\x12\x18\n\x07version\x18\t \x01(\tR\x07version\x12I\n\tresources\x18\n \x01(\x0b\x32+.doublecloud.clickhouse.v1.ClusterResourcesR\tresources\x12R\n\x0f\x63onnection_info\x18\x0b \x01(\x0b\x32).doublecloud.clickhouse.v1.ConnectionInfoR\x0e\x63onnectionInfo\x12.\n\x06\x61\x63\x63\x65ss\x18\x0c \x01(\x0b\x32\x16.doublecloud.v1.AccessR\x06\x61\x63\x63\x65ss\x12h\n\x17private_connection_info\x18\r \x01(\x0b\x32\x30.doublecloud.clickhouse.v1.PrivateConnectionInfoR\x15privateConnectionInfo\x12>\n\nencryption\x18\x0e \x01(\x0b\x32\x1e.doublecloud.v1.DataEncryptionR\nencryption\x12\x1d\n\nnetwork_id\x18\x0f \x01(\tR\tnetworkId\x12X\n\x11\x63lickhouse_config\x18\x10 \x01(\x0b\x32+.doublecloud.clickhouse.v1.ClickhouseConfigR\x10\x63lickhouseConfig\x12P\n\x12maintenance_window\x18\x11 \x01(\x0b\x32!.doublecloud.v1.MaintenanceWindowR\x11maintenanceWindow\x12Y\n\x15maintenance_operation\x18\x12 \x01(\x0b\x32$.doublecloud.v1.MaintenanceOperationR\x14maintenanceOperation\"\xe1\x02\n\x10\x43lusterResources\x12V\n\nclickhouse\x18\x01 \x01(\x0b\x32\x36.doublecloud.clickhouse.v1.ClusterResources.ClickhouseR\nclickhouse\x1a\xf4\x01\n\nClickhouse\x12,\n\x12resource_preset_id\x18\x01 \x01(\tR\x10resourcePresetId\x12\x38\n\tdisk_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x08\x64iskSize\x12@\n\rreplica_count\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0creplicaCount\x12<\n\x0bshard_count\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nshardCount\"\xd1\x02\n\x0e\x43onnectionInfo\x12\x12\n\x04host\x18\x01 \x01(\tR\x04host\x12\x12\n\x04user\x18\x02 \x01(\tR\x04user\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12:\n\nhttps_port\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\thttpsPort\x12\x43\n\x0ftcp_port_secure\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\rtcpPortSecure\x12\'\n\x0fnative_protocol\x18\x06 \x01(\tR\x0enativeProtocol\x12\x1b\n\thttps_uri\x18\x07 \x01(\tR\x08httpsUri\x12\x19\n\x08jdbc_uri\x18\x08 \x01(\tR\x07jdbcUri\x12\x19\n\x08odbc_uri\x18\t \x01(\tR\x07odbcUri\"\xd8\x02\n\x15PrivateConnectionInfo\x12\x12\n\x04host\x18\x01 \x01(\tR\x04host\x12\x12\n\x04user\x18\x02 \x01(\tR\x04user\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12:\n\nhttps_port\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\thttpsPort\x12\x43\n\x0ftcp_port_secure\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\rtcpPortSecure\x12\'\n\x0fnative_protocol\x18\x06 \x01(\tR\x0enativeProtocol\x12\x1b\n\thttps_uri\x18\x07 \x01(\tR\x08httpsUri\x12\x19\n\x08jdbc_uri\x18\x08 \x01(\tR\x07jdbcUri\x12\x19\n\x08odbc_uri\x18\t \x01(\tR\x07odbcUri\"{\n\x04Host\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12\x1d\n\nshard_name\x18\x03 \x01(\tR\tshardName\x12!\n\x0cprivate_name\x18\x04 \x01(\tR\x0bprivateNameBAZ?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.clickhouse.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouse'
  _globals['_CLUSTER']._serialized_start=240
  _globals['_CLUSTER']._serialized_end=1223
  _globals['_CLUSTERRESOURCES']._serialized_start=1226
  _globals['_CLUSTERRESOURCES']._serialized_end=1579
  _globals['_CLUSTERRESOURCES_CLICKHOUSE']._serialized_start=1335
  _globals['_CLUSTERRESOURCES_CLICKHOUSE']._serialized_end=1579
  _globals['_CONNECTIONINFO']._serialized_start=1582
  _globals['_CONNECTIONINFO']._serialized_end=1919
  _globals['_PRIVATECONNECTIONINFO']._serialized_start=1922
  _globals['_PRIVATECONNECTIONINFO']._serialized_end=2266
  _globals['_HOST']._serialized_start=2268
  _globals['_HOST']._serialized_end=2391
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/clickhouse/v1/backup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&doublecloud/clickhouse/v1/backup.proto\x12\x19\x64oublecloud.clickhouse.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfe\x02\n\x06\x42\x61\x63kup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12;\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12\x39\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12*\n\x11source_cluster_id\x18\x06 \x01(\tR\x0fsourceClusterId\x12\x12\n\x04size\x18\x07 \x01(\x03R\x04size\x12:\n\x04type\x18\x08 \x01(\x0e\x32&.doublecloud.clickhouse.v1.Backup.TypeR\x04type\"=\n\x04Type\x12\x10\n\x0cTYPE_INVALID\x10\x00\x12\x12\n\x0eTYPE_AUTOMATED\x10\x01\x12\x0f\n\x0bTYPE_MANUAL\x10\x02\x42\x41Z?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.clickhouse.v1.backup_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouse'
  _globals['_BACKUP']._serialized_start=103
  _globals['_BACKUP']._serialized_end=485
  _globals['_BACKUP_TYPE']._serialized_start=424
  _globals['_BACKUP_TYPE']._serialized_end=485
# @@protoc_insertion_point(module_scope)



import grpc

from doublecloud import _auth_plugin
from doublecloud import _consts as const
from doublecloud._auth_fabric import get_auth_token_requester


class Channels(object):
    def __init__(self, client_user_agent=None, **kwargs):
        self._channel_creds = grpc.ssl_channel_credentials(
            root_certificates=kwargs.get("root_certificates"),
            private_key=kwargs.get("private_key"),
            certificate_chain=kwargs.get("certificate_chain"),
        )
        self._endpoint = kwargs.get("endpoint", const.get_endpoint())
        self._token_requester = get_auth_token_requester(
            service_account_key=kwargs.get("service_account_key"),
            iam_token=kwargs.get("iam_token"),
            endpoint=self._endpoint,
            user_agent=kwargs.get("user_agent", const.SDK_USER_AGENT),
        )

        self._unauthenticated_channel = None
        self._channels = None
        self._client_user_agent = client_user_agent

    def channel_options(self):
        return tuple(
            ("grpc.primary_user_agent", user_agent)
            for user_agent in [self._client_user_agent, const.SDK_USER_AGENT]
            if user_agent is not None
        )

    def _get_endpoints(self):
        return {
            "clickhouse": f"clickhouse.api.{self._endpoint}:443",
            "kafka": f"kafka.api.{self._endpoint}:443",
            "network": f"vpc.api.{self._endpoint}:443",
            "transfer": f"transfer.api.{self._endpoint}:443",
            "visualization": f"visualization.api.{self._endpoint}:443",
        }

    def channel(self, endpoint):
        if not self._channels:
            self._unauthenticated_channel = grpc.secure_channel(
                self._endpoint, self._channel_creds, options=self.channel_options()
            )

            plugin = _auth_plugin.Credentials(self._token_requester)
            call_creds = grpc.metadata_call_credentials(plugin)
            creds = grpc.composite_channel_credentials(self._channel_creds, call_creds)

            self._channels = {
                svc: grpc.secure_channel(addr, creds, options=self.channel_options())
                for svc, addr in self._get_endpoints().items()
            }

        if endpoint not in self._channels:
            raise RuntimeError(f"Unknown endpoint: {endpoint}")

        return self._channels[endpoint]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/network/v1/network_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.network.v1 import network_pb2 as doublecloud_dot_network_dot_v1_dot_network__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,doublecloud/network/v1/network_service.proto\x12\x16\x64oublecloud.network.v1\x1a$doublecloud/network/v1/network.proto\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\"2\n\x11GetNetworkRequest\x12\x1d\n\nnetwork_id\x18\x01 \x01(\tR\tnetworkId\"d\n\x13ListNetworksRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x8a\x01\n\x14ListNetworksResponse\x12;\n\x08networks\x18\x01 \x03(\x0b\x32\x1f.doublecloud.network.v1.NetworkR\x08networks\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"\xcf\x01\n\x14\x43reateNetworkRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x1d\n\ncloud_type\x18\x02 \x01(\tR\tcloudType\x12\x1b\n\tregion_id\x18\x03 \x01(\tR\x08regionId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12&\n\x0fipv4_cidr_block\x18\x06 \x01(\tR\ripv4CidrBlock\"5\n\x14\x44\x65leteNetworkRequest\x12\x1d\n\nnetwork_id\x18\x01 \x01(\tR\tnetworkId\"\xb6\x01\n\x14ImportNetworkRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12?\n\x03\x61ws\x18\x04 \x01(\x0b\x32+.doublecloud.network.v1.ImportAWSVPCRequestH\x00R\x03\x61wsB\x08\n\x06params\"\xbf\x01\n\x13ImportAWSVPCRequest\x12\x15\n\x06vpc_id\x18\x01 \x01(\tR\x05vpcId\x12\x1b\n\tregion_id\x18\x02 \x01(\tR\x08regionId\x12\x1d\n\naccount_id\x18\x03 \x01(\tR\taccountId\x12 \n\x0ciam_role_arn\x18\x04 \x01(\tR\niamRoleArn\x12\x19\n\x08stack_id\x18\x05 \x01(\tR\x07stackId\x12\x18\n\x07version\x18\x06 \x01(\tR\x07version2\xbf\x03\n\x0eNetworkService\x12Q\n\x03Get\x12).doublecloud.network.v1.GetNetworkRequest\x1a\x1f.doublecloud.network.v1.Network\x12\x61\n\x04List\x12+.doublecloud.network.v1.ListNetworksRequest\x1a,.doublecloud.network.v1.ListNetworksResponse\x12Q\n\x06\x43reate\x12,.doublecloud.network.v1.CreateNetworkRequest\x1a\x19.doublecloud.v1.Operation\x12Q\n\x06\x44\x65lete\x12,.doublecloud.network.v1.DeleteNetworkRequest\x1a\x19.doublecloud.v1.Operation\x12Q\n\x06Import\x12,.doublecloud.network.v1.ImportNetworkRequest\x1a\x19.doublecloud.v1.OperationB;Z9github.com/doublecloud/api/doublecloud/network/v1;networkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.network.v1.network_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/doublecloud/api/doublecloud/network/v1;network'
  _globals['_GETNETWORKREQUEST']._serialized_start=171
  _globals['_GETNETWORKREQUEST']._serialized_end=221
  _globals['_LISTNETWORKSREQUEST']._serialized_start=223
  _globals['_LISTNETWORKSREQUEST']._serialized_end=323
  _globals['_LISTNETWORKSRESPONSE']._serialized_start=326
  _globals['_LISTNETWORKSRESPONSE']._serialized_end=464
  _globals['_CREATENETWORKREQUEST']._serialized_start=467
  _globals['_CREATENETWORKREQUEST']._serialized_end=674
  _globals['_DELETENETWORKREQUEST']._serialized_start=676
  _globals['_DELETENETWORKREQUEST']._serialized_end=729
  _globals['_IMPORTNETWORKREQUEST']._serialized_start=732
  _globals['_IMPORTNETWORKREQUEST']._serialized_end=914
  _globals['_IMPORTAWSVPCREQUEST']._serialized_start=917
  _globals['_IMPORTAWSVPCREQUEST']._serialized_end=1108
  _globals['_NETWORKSERVICE']._serialized_start=1111
  _globals['_NETWORKSERVICE']._serialized_end=1558
# @@protoc_insertion_point(module_scope)
